@@ -1,7 +1,7 @@
 #!/bin/sh
 RCDLINKS="2,S41 3,S41 6,K41"
 #
-#     The Shoreline Firewall (Shorewall) Packet Filtering Firewall - V2.2
+#     The Shoreline Firewall (Shorewall) Packet Filtering Firewall - V3.0
 #
 #     This program is under GPL [http://www.gnu.org/copyleft/gpl.htm]
 #
@@ -31,10 +31,15 @@ RCDLINKS="2,S41 3,S41 6,K41"
 #
 #	   shorewall start			  Starts the firewall
 #	   shorewall restart			  Restarts the firewall
+#	   shorewall reload			  Restarts the firewall
 #	   shorewall stop			  Stops the firewall
 #	   shorewall status			  Displays firewall status
 #
-#### BEGIN INIT INFO
+
+# chkconfig: 2345 25 90
+# description: Packet filtering firewall
+
+### BEGIN INIT INFO
 # Provides:	  shorewall
 # Required-Start: $network
 # Required-Stop:
@@ -43,15 +48,11 @@ RCDLINKS="2,S41 3,S41 6,K41"
 # Description:	  starts and stops the shorewall firewall
 ### END INIT INFO
 
-# chkconfig: 2345 25 90
-# description: Packet filtering firewall
-#
-
 ################################################################################
 # Give Usage Information						       #
 ################################################################################
 usage() {
-    echo "Usage: $0 start|stop|restart|status"
+    echo "Usage: $0 start|stop|reload|restart|status"
     exit 1
 }
 
@@ -71,19 +72,17 @@ fi
 command="$1"
 
 case "$command" in
-
     start)
-	
-	exec /sbin/shorewall $OPTIONS start
+	exec /sbin/shorewall $OPTIONS $@
 	;;
-
     stop|restart|status)
-
 	exec /sbin/shorewall $@
 	;;
+    reload)
+	shift
+	exec /sbin/shorewall restart $@
+	;;
     *)
-
 	usage
 	;;
-
 esac
